@@ -1,5 +1,9 @@
 """Implementation of perl Config package"""
 
+__author__ = """Joe Cool"""
+___email__ = 'snoopyjc@gmail.com'
+__version__ = '0.967'
+
 import perllib
 import subprocess
 import traceback
@@ -12,12 +16,12 @@ def config_sh():
 Config.config_sh = config_sh
 
 try:
-    Config.Config = dict()
+    Config.Config_h = dict()
     lines = config_sh().splitlines()
     for line in lines:
         if '=' in line:
             (lhs, rhs) = line.split('=',1)
             rhs = rhs[1:-1] # Eat the quotes
-            Config.Config[lhs] = rhs
+            Config.Config_h[lhs] = rhs
 except Exception:
     traceback.print_exc()
